
%global pkg_name filepath-bytestring
%global pkgver %{pkg_name}-%{version}

%bcond_with tests

Name:           ghc-%{pkg_name}
Version:        1.4.2.1.13
Release:    2%{?dist}
Summary:        Library for manipulating RawFilePaths in a cross platform way

License:        BSD-3-Clause
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkgver}/%{pkgver}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-unix-devel
%if %{with ghc_prof}
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-unix-prof
%endif
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-filepath-devel
%endif

%description
This package provides functionality for manipulating 'RawFilePath' values.
It can be used as a drop in replacement for the filepath library to get the
benefits of using ByteStrings. It provides three modules:

* "System.FilePath.Posix.ByteString" manipulates POSIX/Linux style
'RawFilePath' values (with '/' as the path separator).

* "System.FilePath.Windows.ByteString" manipulates Windows style 'RawFilePath'
values (with either '\' or '/' as the path separator, and deals with drives).

* "System.FilePath.ByteString" is an alias for the module appropriate to your
platform.

All three modules provide the same API, and the same documentation (calling out
differences in the different variants).

This package is now deprecated, since filepath 1.4.100.0 provides an OsPath
type that is based on a bytestring. See
https://hasufell.github.io/posts/2022-06-29-fixing-haskell-filepaths.html.


%package devel
Summary:        Haskell %{pkg_name} library development files
Provides:       %{name}-static = %{version}-%{release}
Provides:       %{name}-static = %{version}-%{release}
%if %{defined ghc_version}
Requires:       ghc-compiler = %{ghc_version}
%endif
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development
files.


%if %{with haddock}
%package doc
Summary:        Haskell %{pkg_name} library documentation
BuildArch:      noarch
Requires:       ghc-filesystem

%description doc
This package provides the Haskell %{pkg_name} library
documentation.
%endif


%if %{with ghc_prof}
%package prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       %{name}-devel = %{version}-%{release}
Supplements:    (%{name}-devel and ghc-prof)

%description prof
This package provides the Haskell %{pkg_name} profiling library.
%endif


%prep
%setup -q -n %{pkgver}


%build
%ghc_lib_build


%install
%ghc_lib_install


%check
%if %{with tests}
%cabal_test
%endif


%files -f %{name}.files
%license LICENSE


%files devel -f %{name}-devel.files
%doc CHANGELOG README.md TODO


%if %{with haddock}
%files doc -f %{name}-doc.files
%license LICENSE
%endif


%if %{with ghc_prof}
%files prof -f %{name}-prof.files
%endif


%changelog
* Thu Jun 05 2025 bbrucezhang <bbrucezhang@tencent.com> - 1.4.2.1.13-2
- Rebuilt for loongarch64

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.2.1.13-1
- initial build
